@@ -22,7 +22,7 @@ if (is.character(name)){
 min.in<-min(min(index.n.chain)*0.9,100)
 max.in<-max(max(index.n.chain)*1.1,100)
 plot(index.n.chain,type="l",xaxt='n',
-     ylim=c(min.in,max.in),xlab="Stages",ylab=name,col="red")
+     ylim=c(min.in,max.in),xlab="Stages",ylab= paste(name,"Index Number",sep=": "),col="red")
                   axis(side = 1, at =seq(1,length(x),by=1),labels=0:(length(x)-1))
 abline(h=100,col="gray",lty=2)
 }else{
